<?php
/**
 * Plugin Name: Kinsey Core
 * Description: Core Plugin for Kinsey WordPress Theme
 * Plugin URI: https://artemsemkin.com/
 * Version: 1.6.6
 * Requires at least: 6.4
 * Requires PHP: 7.0
 * Author: Artem Semkin
 * Update URI: artemsemkin.com
 * Text Domain: kinsey
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

define( 'ARTS_KINSEY_CORE_PLUGIN_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
define( 'ARTS_KINSEY_CORE_PLUGIN_URL', untrailingslashit( plugin_dir_url( __FILE__ ) ) );
define( 'ARTS_KINSEY_CORE_PLUGIN_VERSION', get_file_data( __FILE__, array( 'ver' => 'Version' ), false )['ver'] );

/**
 * Theme Constants
 */
require_once __DIR__ . '/inc/constants.php';

/**
 * Helper Functions
 */
require_once __DIR__ . '/inc/acf_helpers.php';
require_once __DIR__ . '/inc/elementor_helpers.php';

/**
 * Register Custom Elementor Widgets
 */
require_once __DIR__ . '/elementor/kinsey_elementor_extension.php';

/**
 * Extra Panels: Document Settings
 */
require_once __DIR__ . '/elementor/document/page_header.php';
require_once __DIR__ . '/elementor/document/page_masthead.php';
require_once __DIR__ . '/elementor/document/page_bottom_navigation.php';
require_once __DIR__ . '/elementor/document/page_footer.php';
require_once __DIR__ . '/elementor/document/page_ajax.php';

/**
 * Extra Panels: Elementor Section
 */
require_once __DIR__ . '/elementor/section/section_add_render_attributes.php';
require_once __DIR__ . '/elementor/section/section_color_theme_controls.php';
require_once __DIR__ . '/elementor/section/section_color_theme_switch_on_scroll_controls.php';
require_once __DIR__ . '/elementor/section/section_fluid_paddings_margins_controls.php';
require_once __DIR__ . '/elementor/section/section_layout_controls.php';
require_once __DIR__ . '/elementor/section/section_united_inner_galleries.php';

/**
 * Extra Panels: Elementor Column
 */
require_once __DIR__ . '/elementor/column/column_order_controls.php';

/**
 * Register Custom Post Types
 */
require_once __DIR__ . '/inc/cpt.php';

/**
 * Plugin Frontend
 */
require_once __DIR__ . '/inc/frontend/localize_assets.php';

/**
 * Admin Options
 */
require_once __DIR__ . '/inc/options.php';

/**
 * Admin Options
 */
require_once __DIR__ . '/inc/shortcodes.php';

/**
 * Taxonomies
 */
require_once __DIR__ . '/inc/taxonomies.php';

/**
 * Photoswipe Gallery Template
 */
require_once __DIR__ . '/modules/pswp/ajax_get_pswp_gallery_template.php';

/**
 * Plugin Updates API
 */
if ( ! class_exists( 'Arts_Core_Plugin_Update' ) ) {
	require_once __DIR__ . '/inc/update.php';
}
new Arts_Core_Plugin_Update( 'kinsey', 'kinsey-core/kinsey_core.php' );

add_action( 'init', 'arts_load_textdomain' );
function arts_load_textdomain() {
	load_plugin_textdomain( 'kinsey' );
}
